{% extends "!page.html" %} {% block doc_source %} {% endblock %} {% block content %}

# Helps

## Introduction

This help page is not part of document. Help page provides basic concepts and instructions to use document which contains it.

## Full interface

1. `TOC Button`. Go to Table of Contents page.
2. `TOC Panel`. It displays document’s Table of Contents, 3 levels is maximum.
3. `Content Area`. It displays document’s content which corresponds with current section.
4. `Search Box`. It is text input, use for input keywords to search. Searching returns sections which contains keywords. To search, select `Search Box`, type keywords then press `ENTER` key or click to `Search Button` to start
5. `Search Button`. Click to this button start searching.
6. `Mode Label`. Display curent `Shortcut keys` mode.
7. `About Link`. Go to `About Page` where display information about document.
8. `Help Link`. Go to `Help Page` where display basic manual to read document.
9. `Downloads Link`. Go to `Downloads Page` where contains options to download other formats of document.
10. `Source Link`. Go to text file which is source of current section in reStructureText language.
11. `Next Link`. Go to next section. If next section is not available, this link is not shows.
12. `Previous Link`. Go to previous section. If previous section is not available, this link is not shows.

## Basic interface

## Shortcut keys

Key | Description
--- | ---
ESC | Go to NORMAL mode
BACKQUOTE | Go to SEARCH mode
g | Toogle GOTO mode. In this mode, use 0-9 keys and BACKSPACE to select labels then press ENTER key to go to target.
n | Go to next section
p | Go to previous section
t | Go to table of contents
h | Go to help page
a | Go to about page
d | Go to downloads page

{% endblock %}